pub enum MicrosoftAuthError {
AuthorizationPending,
AuthorizationDeclined,
BadVerificationCode,
ExpiredToken,
ReqwesetError(Error),
Others(String),
}Variants
AuthorizationPending
if you get this error, you should try again in interval sec later.
see Microsoft DOCS
AuthorizationDeclined
User declined the authorization.
see Microsoft DOCS
BadVerificationCode
The auth server cannot identify the device code. Please check the device code is correct or not!
see Microsoft DOCS
ExpiredToken
The token is expired.
see Microsoft DOCS
ReqwesetError(Error)
This error is related to the request error.
You can check error details in the inner error.
Others(String)
The error which is not on the list.
You can check error details in the inner string.